@@ -1,15 +1,15 @@
 package Net::DNS::Domain;
 
 #
-# $Id: Domain.pm 1161 2014-01-13 15:48:07Z willem $
+# $Id: Domain.pm 1276 2014-10-19 06:02:40Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1161 $)[1];
+$VERSION = (qw$LastChangedRevision: 1276 $)[1];
 
 
 =head1 NAME
 
-Net::DNS::Domain - Domain Name System domains
+Net::DNS::Domain - DNS domains
 
 =head1 SYNOPSIS
 
@@ -43,12 +43,14 @@ use Carp;
 
 use constant ASCII => eval {
 	require Encode;
-	Encode::find_encoding('ASCII');				# return encoding object
+	Encode::find_encoding('ascii');				# encoding object
+	1;
 } || 0;
 
 use constant UTF8 => eval {
 	die if Encode::decode_utf8( chr(91) ) ne '[';		# not UTF-EBCDIC  [see UTR#16 3.6]
-	Encode::find_encoding('UTF8');				# return encoding object
+	Encode::find_encoding('utf8');				# encoding object
+	1;
 } || 0;
 
 use constant LIBIDN => eval {
@@ -57,6 +59,11 @@ use constant LIBIDN => eval {
 } || 0;
 
 
+# perlcc: address of encoding objects must be determined at runtime
+my $ascii = ASCII ? Encode::find_encoding('ascii') : undef;	# Osborn's Law:
+my $utf8  = UTF8  ? Encode::find_encoding('utf8')  : undef;	# Variables won't; constants aren't.
+
+
 =head1 METHODS
 
 =head2 new
@@ -85,10 +92,7 @@ for zone files described in RFC1035.
 =cut
 
 use vars qw($ORIGIN);
-
-my $cache1 = {};
-my $cache2 = {};
-my $expire;
+my ( $cache1, $cache2, $limit ) = ( {}, {}, 100 );
 
 sub new {
 	my ( $class, $s ) = @_;
@@ -98,7 +102,7 @@ sub new {
 	my $cache = $$cache1{$k} ||= $$cache2{$k};		# two layer cache
 	return $cache if defined $cache;
 
-	( $cache1, $cache2, $expire ) = ( {}, $cache1, 500 ) unless $expire--;	  # recycle cache
+	( $cache1, $cache2, $limit ) = ( {}, $cache1, 500 ) unless $limit--;	# recycle cache
 
 	my $self = bless {}, $class;
 
@@ -136,7 +140,7 @@ numerical escape sequence.
 
 =cut
 
-my $dot = _decode_ascii( pack 'C', 46 );
+my $dot = '.';
 
 sub name {
 	my $self = shift;
@@ -147,7 +151,8 @@ sub name {
 	my $head = _decode_ascii( join chr(46), map _escape($_), @$lref );
 	my $tail = $self->{origin} || return $self->{name} = $head || $dot;
 	return $self->{name} = $tail->name unless length $head;
-	return $self->{name} = join $dot, $head, $tail->name;
+	my $suffix = $tail->name;
+	return $self->{name} = $suffix eq $dot ? $head : join $dot, $head, $suffix;
 }
 
 
@@ -185,7 +190,7 @@ sub xname {
 	return $name unless $name =~ /xn--/;
 
 	my $self = shift;
-	return $self->{xname} ||= UTF8->decode( Net::LibIDN::idn_to_unicode( $name, 'utf-8' ) || $name );
+	return $self->{xname} ||= $utf8->decode( Net::LibIDN::idn_to_unicode( $name, 'utf-8' ) || $name );
 }
 
 
@@ -219,7 +224,7 @@ represented by the appropriate escape sequence.
 =cut
 
 sub string {
-	( my $name = &name ) =~ s/(['"\$;@])/\\$1/;		# escape special char
+	( my $name = &name ) =~ s/(["'\$();@])/\\$1/;		# escape special char
 	return $name =~ /[$dot]$/o ? $name : $name . $dot;	# append trailing dot
 }
 
@@ -239,10 +244,10 @@ where relative names become descendents of the specified $ORIGIN.
 my $placebo = sub { my $constructor = shift; &$constructor; };
 
 sub origin {
-	my $class = shift;
-	my $name = shift || return $placebo;
+	my ( $class, $name ) = @_;
 
-	my $domain = new Net::DNS::Domain($name);
+	my $domain = defined $name ? new Net::DNS::Domain($name) : return $placebo;
+	$domain = undef unless scalar @{$domain->{label}};
 	return sub {						# closure w.r.t. $domain
 		my $constructor = shift;
 		local $ORIGIN = $domain;			# dynamically scoped $ORIGIN
@@ -270,7 +275,7 @@ sub _decode_ascii {			## translate ASCII to perl string
 
 	my $t = substr $s, 0, 0;				# pre-5.18 taint workaround
 	my $z = length $t;
-	return pack "x$z a*", ASCII->decode($s) if ASCII;
+	return pack "a* x$z", $ascii->decode($s) if ASCII;
 
 	# partial transliteration for non-ASCII character encodings
 	$s =~ tr
@@ -286,10 +291,10 @@ sub _encode_ascii {			## translate perl string to ASCII
 
 	my $t = substr $s, 0, 0;				# pre-5.18 taint workaround
 	my $z = length $t;
-	return pack "x$z a*", Net::LibIDN::idn_to_ascii( $s, 'utf-8' ) || croak 'invalid name'
+	return pack "a* x$z", Net::LibIDN::idn_to_ascii( $s, 'utf-8' ) || croak 'invalid name'
 			if LIBIDN && $s =~ /[^\000-\177]/;
 
-	return pack "x$z a*", ASCII->encode($s) if ASCII;
+	return pack "a* x$z", $ascii->encode($s) if ASCII;
 
 	# partial transliteration for non-ASCII character encodings
 	$s =~ tr
@@ -312,8 +317,13 @@ my %esc = eval {			## precalculated ASCII escape table
 		$table{pack( 'C', $_ )} = pack 'C*', 92, $_;
 	}
 
-	foreach ( 0 .. 32, 127 .. 255 ) {			# \ddd
-		$table{pack( 'C', $_ )} = sprintf '\\%03u', $_;
+	foreach my $n ( 0 .. 32, 127 .. 255 ) {			# \ddd
+		my $codepoint = sprintf( '%03u', $n );
+
+		# partial transliteration for non-ASCII character encodings
+		$codepoint =~ tr [0-9] [\060-\071];
+
+		$table{pack( 'C', $n )} = pack 'C a3', 92, $codepoint;
 	}
 
 	return %table;
@@ -330,11 +340,15 @@ sub _escape {				## Insert escape sequences in string
 my %unesc = eval {			## precalculated numeric escape table
 	my %table;
 
-	foreach ( 0 .. 255 ) {
-		$table{_encode_ascii sprintf( '%03u', $_ )} = pack 'C', $_;
-	}
+	foreach my $n ( 0 .. 255 ) {
+		my $key = sprintf( '%03u', $n );
 
-	$table{_encode_ascii('092')} = pack 'C*', 92, 92;	# escaped escape
+		# partial transliteration for non-ASCII character encodings
+		$key =~ tr [0-9] [\060-\071];
+
+		$table{$key} = pack 'C', $n;
+		$table{$key} = pack 'C2', 92, $n if $n == 92;	# escaped escape
+	}
 
 	return %table;
 };
