@@ -1,12 +1,14 @@
 package Net::DNS::RR::AFSDB;
 
 #
-# $Id: AFSDB.pm 1068 2012-12-06 10:38:51Z willem $
+# $Id: AFSDB.pm 1326 2015-02-18 10:51:24Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1068 $)[1];
+$VERSION = (qw$LastChangedRevision: 1326 $)[1];
 
-use base Net::DNS::RR;
+
+use strict;
+use base qw(Net::DNS::RR);
 
 =head1 NAME
 
@@ -15,7 +17,6 @@ Net::DNS::RR::AFSDB - DNS AFSDB resource record
 =cut
 
 
-use strict;
 use integer;
 
 use Net::DNS::DomainName;
@@ -26,7 +27,7 @@ sub decode_rdata {			## decode rdata from wire-format octet string
 	my ( $data, $offset, @opaque ) = @_;
 
 	$self->{subtype} = unpack "\@$offset n", $$data;
-	$self->{hostname} = decode Net::DNS::DomainName2535($data,$offset+2,@opaque );
+	$self->{hostname} = decode Net::DNS::DomainName2535( $data, $offset + 2, @opaque );
 }
 
 
@@ -51,22 +52,24 @@ sub format_rdata {			## format rdata portion of RR string.
 sub parse_rdata {			## populate RR from rdata in argument list
 	my $self = shift;
 
-	$self->$_(shift) for qw(subtype hostname);
+	$self->subtype(shift);
+	$self->hostname(shift);
 }
 
 
 sub subtype {
 	my $self = shift;
 
-	$self->{subtype} = shift if @_;
-	return 0 + ( $self->{subtype} || 0 );
+	$self->{subtype} = 0 + shift if scalar @_;
+	return $self->{subtype} || 0;
 }
 
+
 sub hostname {
 	my $self = shift;
 
-	$self->{hostname} = new Net::DNS::DomainName2535(shift) if @_;
-	$self->{hostname}->name if defined wantarray;
+	$self->{hostname} = new Net::DNS::DomainName2535(shift) if scalar @_;
+	$self->{hostname}->name if defined wantarray && $self->{hostname};
 }
 
 1;
@@ -95,6 +98,7 @@ other unpredictable behaviour.
 =head2 subtype
 
     $subtype = $rr->subtype;
+    $rr->subtype( $subtype );
 
 A 16 bit integer which indicates the service offered by the
 listed host.
@@ -102,6 +106,7 @@ listed host.
 =head2 hostname
 
     $hostname = $rr->hostname;
+    $rr->hostname( $hostname );
 
 The hostname field is a domain name of a host that has a server
 for the cell named by the owner name of the RR.
@@ -111,13 +116,13 @@ for the cell named by the owner name of the RR.
 
 Copyright (c)1997-1998 Michael Fuhr. 
 
-Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
-
 All rights reserved.
 
 This program is free software; you may redistribute it and/or
 modify it under the same terms as Perl itself.
 
+Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
+
 
 =head1 SEE ALSO
 
