@@ -1,12 +1,14 @@
 package Net::DNS::RR::CNAME;
 
 #
-# $Id: CNAME.pm 1068 2012-12-06 10:38:51Z willem $
+# $Id: CNAME.pm 1326 2015-02-18 10:51:24Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1068 $)[1];
+$VERSION = (qw$LastChangedRevision: 1326 $)[1];
 
-use base Net::DNS::RR;
+
+use strict;
+use base qw(Net::DNS::RR);
 
 =head1 NAME
 
@@ -15,7 +17,6 @@ Net::DNS::RR::CNAME - DNS CNAME resource record
 =cut
 
 
-use strict;
 use integer;
 
 use Net::DNS::DomainName;
@@ -54,8 +55,8 @@ sub parse_rdata {			## populate RR from rdata in argument list
 sub cname {
 	my $self = shift;
 
-	$self->{cname} = new Net::DNS::DomainName1035(shift) if @_;
-	$self->{cname}->name if defined wantarray;
+	$self->{cname} = new Net::DNS::DomainName1035(shift) if scalar @_;
+	$self->{cname}->name if defined wantarray && $self->{cname};
 }
 
 1;
@@ -90,6 +91,7 @@ other unpredictable behaviour.
 =head2 cname
 
     $cname = $rr->cname;
+    $rr->cname( $cname );
 
 A domain name which specifies the canonical or primary name for
 the owner.  The owner name is an alias.
@@ -101,13 +103,13 @@ Copyright (c)1997-2002 Michael Fuhr.
 
 Portions Copyright (c)2002-2004 Chris Reinhardt.
 
-Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
-
 All rights reserved.
 
 This program is free software; you may redistribute it and/or
 modify it under the same terms as Perl itself.
 
+Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
+
 
 =head1 SEE ALSO
 
