@@ -1,10 +1,10 @@
 package Net::DNS::RR::MR;
 
 #
-# $Id: MR.pm 1182 2014-04-03 08:52:00Z willem $
+# $Id: MR.pm 1326 2015-02-18 10:51:24Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1182 $)[1];
+$VERSION = (qw$LastChangedRevision: 1326 $)[1];
 
 
 use strict;
@@ -54,7 +54,7 @@ sub newname {
 	my $self = shift;
 
 	$self->{newname} = new Net::DNS::DomainName1035(shift) if scalar @_;
-	$self->{newname}->name if defined wantarray;
+	$self->{newname}->name if defined wantarray && $self->{newname};
 }
 
 1;
