@@ -1,12 +1,14 @@
 package Net::DNS::RR::RT;
 
 #
-# $Id: RT.pm 1068 2012-12-06 10:38:51Z willem $
+# $Id: RT.pm 1326 2015-02-18 10:51:24Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1068 $)[1];
+$VERSION = (qw$LastChangedRevision: 1326 $)[1];
 
-use base Net::DNS::RR;
+
+use strict;
+use base qw(Net::DNS::RR);
 
 =head1 NAME
 
@@ -15,7 +17,6 @@ Net::DNS::RR::RT - DNS RT resource record
 =cut
 
 
-use strict;
 use integer;
 
 use Net::DNS::DomainName;
@@ -26,7 +27,7 @@ sub decode_rdata {			## decode rdata from wire-format octet string
 	my ( $data, $offset, @opaque ) = @_;
 
 	$self->{preference} = unpack( "\@$offset n", $$data );
-	$self->{intermediate} = decode Net::DNS::DomainName2535($data,$offset+2,@opaque );
+	$self->{intermediate} = decode Net::DNS::DomainName2535( $data, $offset + 2, @opaque );
 }
 
 
@@ -50,39 +51,35 @@ sub format_rdata {			## format rdata portion of RR string.
 sub parse_rdata {			## populate RR from rdata in argument list
 	my $self = shift;
 
-	$self->$_(shift) for qw(preference intermediate);
+	$self->preference(shift);
+	$self->intermediate(shift);
 }
 
 
 sub preference {
 	my $self = shift;
 
-	$self->{preference} = shift if @_;
-	return 0 + ( $self->{preference} || 0 );
+	$self->{preference} = 0 + shift if scalar @_;
+	return $self->{preference} || 0;
 }
 
+
 sub intermediate {
 	my $self = shift;
 
-	$self->{intermediate} = new Net::DNS::DomainName2535(shift) if @_;
-	$self->{intermediate}->name if defined wantarray;
+	$self->{intermediate} = new Net::DNS::DomainName2535(shift) if scalar @_;
+	$self->{intermediate}->name if defined wantarray && $self->{intermediate};
 }
 
-# sort RRs in numerically ascending order.
-__PACKAGE__->set_rrsort_func(
+
+__PACKAGE__->set_rrsort_func(		## sort RRs in numerically ascending order.
 	'preference',
-	sub {
-		my ( $a, $b ) = ( $Net::DNS::a, $Net::DNS::b );
-		$a->{preference} <=> $b->{preference};
-	} );
-
-
-__PACKAGE__->set_rrsort_func(
-	'default_sort',
-	__PACKAGE__->get_rrsort_func('preference')
+	sub { $Net::DNS::a->{'preference'} <=> $Net::DNS::b->{'preference'} }
 
 	);
 
+__PACKAGE__->set_rrsort_func( 'default_sort', __PACKAGE__->get_rrsort_func('preference') );
+
 1;
 __END__
 
@@ -109,6 +106,7 @@ other unpredictable behaviour.
 =head2 preference
 
     $preference = $rr->preference;
+    $rr->preference( $preference );
 
  A 16 bit integer representing the preference of the route.
 Smaller numbers indicate more preferred routes.
@@ -116,6 +114,7 @@ Smaller numbers indicate more preferred routes.
 =head2 intermediate
 
     $intermediate = $rr->intermediate;
+    $rr->intermediate( $intermediate );
 
 The domain name of a host which will serve as an intermediate
 in reaching the host specified by the owner name.
@@ -127,13 +126,13 @@ to include at least one A, X25, or ISDN record.
 
 Copyright (c)1997-2002 Michael Fuhr. 
 
-Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
-
 All rights reserved.
 
 This program is free software; you may redistribute it and/or
 modify it under the same terms as Perl itself.
 
+Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
+
 
 =head1 SEE ALSO
 
