@@ -1,10 +1,10 @@
 package Net::DNS::RR::SSHFP;
 
 #
-# $Id: SSHFP.pm 1188 2014-04-03 18:54:34Z willem $
+# $Id: SSHFP.pm 1326 2015-02-18 10:51:24Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1188 $)[1];
+$VERSION = (qw$LastChangedRevision: 1326 $)[1];
 
 
 use strict;
@@ -94,8 +94,7 @@ sub fpbin {
 
 
 sub babble {
-	return Digest::BubbleBabble::bubblebabble( Digest => shift->fpbin ) if BABBLE;
-	return '';
+	return BABBLE ? Digest::BubbleBabble::bubblebabble( Digest => shift->fpbin ) : '';
 }
 
 
