@@ -1,10 +1,10 @@
 package Net::DNS::RR::TXT;
 
 #
-# $Id: TXT.pm 1206 2014-05-23 19:53:28Z willem $
+# $Id: TXT.pm 1235 2014-07-29 07:58:19Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1206 $)[1];
+$VERSION = (qw$LastChangedRevision: 1235 $)[1];
 
 
 use strict;
@@ -20,6 +20,7 @@ Net::DNS::RR::TXT - DNS TXT resource record
 
 
 use integer;
+
 use Carp;
 use Net::DNS::Text;
 
@@ -52,7 +53,21 @@ sub format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
 	my $txtdata = $self->{txtdata} || [];
-	join ' ', map $_->string, @$txtdata;
+	my @txtdata = map $_->string, @$txtdata;
+	my @line;
+	my $size = 32;
+	while (@txtdata) {
+		my @group;
+		while ( $size > 0 && scalar @txtdata ) {
+			my $string = shift @txtdata;
+			push @group, $string;
+			$size -= 1 + length($string);
+		}
+		push @line, join ' ', @group;
+		$size = 64;
+	}
+	my $rdata = join "\n", @line;
+	return $rdata =~ /\n/ ? "( $rdata )" : $rdata;
 }
 
 
@@ -78,19 +93,6 @@ sub txtdata {
 
 sub char_str_list { return (&txtdata); }
 
-sub rdatastr {			## SpamAssassin workaround, per CPAN RT#81760
-	my $txtdata = shift->{txtdata} || [];
-	join ' ', map $_->quoted_string, @$txtdata;
-}
-
-package Net::DNS::Text;
-
-sub quoted_string {
-	my $string = shift->string;
-	return $string if $string =~ /^$|\s|["\$'();@]/;	# should already be quoted
-	join '', '"', $string, '"';				# quote previously unquoted string
-}
-
 1;
 __END__
 
